@@ -1,5 +1,7 @@
 DEFAULT_METADATA_TABLE = 'data'
 DEFAULT_USER_TABLE = 'user'
+DEFAULT_NAME_COLUMN = 'dataset'
+DEFAULT_UPDATE_COLUMN = 'updated_at'
 DEFAULT_RESTRICTED_TABLES = [DEFAULT_METADATA_TABLE, DEFAULT_USER_TABLE]
 DEFAULT_METADATA_COLUMNS = [
     dict(name='id', type_='Integer', primary_key=True),
